# Dutch ASA Questionnaire Translation - Translation and Formative Assessment: Round 3
## Overview of Steps to Reproduce Analyses

**Author**: Nele Albers

**Date**: March 2024

**Contributors**: Nele Albers, Willem-Paul Brinkman

**Code based on the code from**: Johan Hensman, Kriss Tesink

**OSF pre-registration**: https://osf.io/adknw


This file is meant to give an overview of how you can inspect/reproduce our analyses. Code was written by Nele Albers based on the code by Johan Hensman and Kriss Tesink for the first two Dutch translation rounds (https://doi.org/10.4121/9db602be-f748-46d7-b75d-874a1a0c244f.v1).


### Types of analyses/material

We describe how you can inspect and/or reproduce our steps and results below.


#### Anonymization code

The folder "Anonymization Code" contains the code for anonymizing participants’ data. We cannot publish non-anonymized data, but we can provide information on how the data was anonymized.


#### Data

The folder "Data" contains the anonymized data from the questionnaire and from participants' Prolific profiles. For each data file, there is a corresponding .xlsx-file that explains the data columns. For example, the file "Final_ASA_Dutch_Round_3_data_explanation.xlsx" explains the data columns in the file "Final_ASA_Dutch_Round_3_anonym.csv."


#### ICC calculations for third translation round and overall best translations

We provide an .Rmd-file to reproduce our calculation of the ICC-values for the third translation round.

The reproduction of our code is based on Docker and R Studio. Take the following steps:
1. Make sure you have Docker installed. You can check if you do by running `docker -v`.
2. Navigate to the folder this README-file is in.
3. Now you have 2 options:
      - Build the Docker image via `docker build . -t gbna4/asaq_dutch_round3`. If this fails, pull the Docker image from Dockerhub instead.
      - Pull the Docker image from Dockerhub via `docker pull gbna4/asaq_dutch_round3`.
4. Run the Docker container via `docker run -d -p 8787:8787 -v <path_to_this_directory>:/home/rstudio/analysis -e PASSWORD=<some_password> gbna4/asaq_dutch_round3`.
5. Go to localhost:8787.
6. Login with username 'rstudio' and the password chosen in step 4.
7. Navigate to the "analysis"-folder in R Studio.
9. Now you can reproduce the analysis results using the .Rmd-file "ICC_Round_3_Dutch.Rmd."


The file "Dutch_ASAQ_Final_Translations_for_Summative_Analysis.xlsx" further shows the best Dutch translation for each of the 90 English ASAQ items after the 3 translation rounds, including the corresponding ICC-values.


### Files and folders

This directory contains the following files and folders:

- Anonymization Code:
   - anonymize_and_preprocess_third_dutch_translation_round.py: Code that shows how we anonymized participants' data.

- Data:
   - Final_ASA_Dutch_Round_3_anonym.csv: Anonymized questionnaire data.
   - Final_ASA_Dutch_Round_3_data_explanation.xlsx: File that explains the columns in the file above.
   - prolific_export_dutch_round3_anonym.csv: Anonymized Prolific profile data (e.g., age).
   - prolific_export_dutch_round3_data_explanation.xlsx: File that explains the columns of the file above.
   
- Dockerfile: File with which you can build the Docker image yourself.
- Dutch_ASAQ_Final_Translations_for_Summative_Analysis.xlsx: Best Dutch translation for each of the 90 English ASAQ items after the 3 translation rounds.
- ICC_Round_3_Dutch.pdf: ICC-results that we obtained.
- ICC_Round_3_Dutch.Rmd: .Rmd-file to reproduce the ICC-results yourself.
- README.md/README.pdf: This README-file.
- references.bib: References used in the .Rmd-file.
